=======
mscales
=======

``mscales`` is a Python package to generate, visualize,
and sonify musical scales.

.. image:: _static/sharon-mccutcheon-igBvG1AKTY8-unsplash.jpg
   :align: center
   :alt: Photo by `Sharon McCutcheon <https://unsplash.com/@sharonmccutcheon>`_.

.. toctree::
   :caption: Contents
   :maxdepth: 2

   quickstart
   scales
   basic

.. toctree::
   :maxdepth: 1
   :hidden:

   release-history
